[QGIS Commit] r10836 - in trunk/qgis: python/core src/core

svn_qgis at osgeo.org svn_qgis at osgeo.org
Fri May 22 06:58:55 EDT 2009


Author: wonder
Date: 2009-05-22 06:58:55 -0400 (Fri, 22 May 2009)
New Revision: 10836

Modified:
   trunk/qgis/python/core/qgsgeometry.sip
   trunk/qgis/src/core/qgsgeometry.h
Log:
Fixed documentation of QgsGeometry::asMulti*() functions


Modified: trunk/qgis/python/core/qgsgeometry.sip
===================================================================
--- trunk/qgis/python/core/qgsgeometry.sip	2009-05-22 06:58:00 UTC (rev 10835)
+++ trunk/qgis/python/core/qgsgeometry.sip	2009-05-22 10:58:55 UTC (rev 10836)
@@ -272,16 +272,16 @@
         if wkbType is WKBPolygon, otherwise an empty list */
     QgsPolygon asPolygon();
     
-    /** return contents of the geometry as a polygon
-        if wkbType is WKBPolygon, otherwise an empty list */
+    /** return contents of the geometry as a multi point
+        if wkbType is WKBMultiPint, otherwise an empty list */
     QgsMultiPoint asMultiPoint();
     
-    /** return contents of the geometry as a polygon
-        if wkbType is WKBPolygon, otherwise an empty list */
+    /** return contents of the geometry as a multi linestring
+        if wkbType is WKBMultiLineString, otherwise an empty list */
     QgsMultiPolyline asMultiPolyline();
     
-    /** return contents of the geometry as a polygon
-        if wkbType is WKBPolygon, otherwise an empty list */
+    /** return contents of the geometry as a multi polygon
+        if wkbType is WKBMultiPolygon, otherwise an empty list */
     QgsMultiPolygon asMultiPolygon();
 
     /** return contents of the geometry as a list of geometries

Modified: trunk/qgis/src/core/qgsgeometry.h
===================================================================
--- trunk/qgis/src/core/qgsgeometry.h	2009-05-22 06:58:00 UTC (rev 10835)
+++ trunk/qgis/src/core/qgsgeometry.h	2009-05-22 10:58:55 UTC (rev 10836)
@@ -316,16 +316,16 @@
         if wkbType is WKBPolygon, otherwise an empty list */
     QgsPolygon asPolygon();
 
-    /** return contents of the geometry as a polygon
-        if wkbType is WKBPolygon, otherwise an empty list */
+    /** return contents of the geometry as a multi point
+        if wkbType is WKBMultiPoint, otherwise an empty list */
     QgsMultiPoint asMultiPoint();
 
-    /** return contents of the geometry as a polygon
-        if wkbType is WKBPolygon, otherwise an empty list */
+    /** return contents of the geometry as a multi linestring
+        if wkbType is WKBMultiLineString, otherwise an empty list */
     QgsMultiPolyline asMultiPolyline();
 
-    /** return contents of the geometry as a polygon
-        if wkbType is WKBPolygon, otherwise an empty list */
+    /** return contents of the geometry as a multi polygon
+        if wkbType is WKBMultiPolygon, otherwise an empty list */
     QgsMultiPolygon asMultiPolygon();
 
     /** return contents of the geometry as a list of geometries



More information about the QGIS-commit mailing list